pkglts\.option\.plugin\_project package
=======================================

Submodules
----------

pkglts\.option\.plugin\_project\.config module
----------------------------------------------

.. automodule:: pkglts.option.plugin_project.config
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pkglts.option.plugin_project
    :members:
    :undoc-members:
    :show-inheritance:
